@@ -330,6 +330,10 @@ class ModelBase(object):
         """Call ``session.expunge()`` on ``self``"""
         self.session().expunge(self, *args, **kargs)
 
+    def is_modified(self, *args, **kargs):
+        """Call ``session.is_modified()`` on ``self``"""
+        return self.session().is_modified(self, *args, **kargs)
+
     @classmethod
     def get(cls, *args, **kargs):
         """Proxy to ``cls.query.get()``"""
@@ -343,6 +347,16 @@ class ModelBase(object):
         data = data_dict if isinstance(data_dict, dict) else kargs
         return cls.query.filter_by(**data).first()
 
+    @classmethod
+    def filter(cls, *args, **kargs):
+        """Proxy to ``cls.query.filter()``"""
+        return cls.query.filter(*args, **kargs)
+
+    @classmethod
+    def filter_by(cls, *args, **kargs):
+        """Proxy to ``cls.query.filter_by()``"""
+        return cls.query.filter_by(*args, **kargs)
+
     ##
     # SQLAlchemy.inspect() based methods/properties
     ##
